# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CardiacVTKLoader

.. autofunction:: CardiacVTKLoader

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CardiacVTKLoader(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, polylines=None, edges=None, triangles=None, quads=None, polygons=None, highOrderEdgePositions=None, highOrderTrianglePositions=None, highOrderQuadPositions=None, tetrahedra=None, hexahedra=None, pentahedra=None, highOrderTetrahedronPositions=None, highOrderHexahedronPositions=None, pyramids=None, normals=None, edgesGroups=None, trianglesGroups=None, quadsGroups=None, polygonsGroups=None, tetrahedraGroups=None, hexahedraGroups=None, pentahedraGroups=None, pyramidsGroups=None, flipNormals=None, triangulate=None, createSubelements=None, onlyAttachedPoints=None, translation=None, rotation=None, scale3d=None, transformation=None, createFibers=None, outputNodeFibers=None, outputTetraFibers=None, TetraTriangle=None, unitTime=None, TetraZoneName=None, PointZoneName=None, withAHA=None, TriZoneName=None, AHAzoneName=None, startContraction=None, angleEpi=None, angleEndo=None, CellTypes=None, numberOfZone=None, m_zoneNames=None, m_zoneSizes=None, numberOfSurfaceZone=None, m_surfaceZoneNames=None, m_surfaceZoneSizes=None, MSinitSurfaceZoneNames=None, FileNodeFiber=None, nodeFibers=None, FileFacetFiber=None, facetFibers=None, FileFacetBFiber=None, facetBFibers=None, FileTetraTensor=None, tetraTensor=None, FileContractionParameters=None, ContractionParameters=None, InputContractionParameters=None, FileTetraConductivity=None, tetraConductivity=None, FileStiffnessParameters=None, StiffnessParameters=None, InputStiffnessParameters=None, ElectroFile=None, depoTimes=None, APDTimes=None, APDTimesZones=None, APDTimesString=None, APDTimesFile=None, velocityFile=None, velocities=None, **kwargs):
    """
    Specific mesh loader for different tetrahedron files formats.


    :param name: object name  Default value: CardiacVTKLoader

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Invalid

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the object  Default value: 

    :param position: Vertices of the mesh loaded  Default value: []

    :param polylines: Polylines of the mesh loaded  Default value: []

    :param edges: Edges of the mesh loaded  Default value: []

    :param triangles: Triangles of the mesh loaded  Default value: []

    :param quads: Quads of the mesh loaded  Default value: []

    :param polygons: Polygons of the mesh loaded  Default value: []

    :param highOrderEdgePositions: High order edge points of the mesh loaded  Default value: []

    :param highOrderTrianglePositions: High order triangle points of the mesh loaded  Default value: []

    :param highOrderQuadPositions: High order quad points of the mesh loaded  Default value: []

    :param tetrahedra: Tetrahedra of the mesh loaded  Default value: []

    :param hexahedra: Hexahedra of the mesh loaded  Default value: []

    :param pentahedra: Pentahedra of the mesh loaded  Default value: []

    :param highOrderTetrahedronPositions: High order tetrahedron points of the mesh loaded  Default value: []

    :param highOrderHexahedronPositions: High order hexahedron points of the mesh loaded  Default value: []

    :param pyramids: Pyramids of the mesh loaded  Default value: []

    :param normals: Normals of the mesh loaded  Default value: []

    :param edgesGroups: Groups of Edges  Default value: 

    :param trianglesGroups: Groups of Triangles  Default value: 

    :param quadsGroups: Groups of Quads  Default value: 

    :param polygonsGroups: Groups of Polygons  Default value: 

    :param tetrahedraGroups: Groups of Tetrahedra  Default value: 

    :param hexahedraGroups: Groups of Hexahedra  Default value: 

    :param pentahedraGroups: Groups of Pentahedra  Default value: 

    :param pyramidsGroups: Groups of Pyramids  Default value: 

    :param flipNormals: Flip Normals  Default value: 0

    :param triangulate: Divide all polygons into triangles  Default value: 0

    :param createSubelements: Divide all n-D elements into their (n-1)-D boundary elements (e.g. tetrahedra to triangles)  Default value: 0

    :param onlyAttachedPoints: Only keep points attached to elements of the mesh  Default value: 0

    :param translation: Translation of the DOFs  Default value: [[0.0, 0.0, 0.0]]

    :param rotation: Rotation of the DOFs  Default value: [[0.0, 0.0, 0.0]]

    :param scale3d: Scale of the DOFs in 3 dimensions  Default value: [[1.0, 1.0, 1.0]]

    :param transformation: 4x4 Homogeneous matrix to transform the DOFs (when present replace any)  Default value: [[1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0]]

    :param createFibers: if the loader must create the Fibers  Default value: 0

    :param outputNodeFibers: output Fibers  Default value: 

    :param outputTetraFibers: output Tetra Fibers  Default value: 

    :param TetraTriangle: Tetra or Triangle mesh  Default value: 

    :param unitTime: unit of the time scale use for electrophysiology (s or ms)  Default value: 

    :param TetraZoneName: name of the tetra data   Default value: LVRVTetrazones

    :param PointZoneName: PointZoneName  Default value: 

    :param withAHA: with AHA zones  Default value: 0

    :param TriZoneName: name of the endo epi data  Default value: 

    :param AHAzoneName: name of the tetra data   Default value: AHATetraZones

    :param startContraction: time at which the contraction starts  Default value: 0.0

    :param angleEpi: if the loader must create the Fibers  Default value: 0.0

    :param angleEndo: if the loader must create the Fibers  Default value: 0.0

    :param CellTypes: Type of each cell element  Default value: []

    :param numberOfZone: Vertices of the mesh loaded  Default value: 0

    :param m_zoneNames: See zones Name.  Default value: []

    :param m_zoneSizes: See zones Size.  Default value: []

    :param numberOfSurfaceZone: Vertices of the mesh loaded  Default value: 0

    :param m_surfaceZoneNames: See surface zones Name.  Default value: []

    :param m_surfaceZoneSizes: See surface zones Size.  Default value: []

    :param MSinitSurfaceZoneNames: Input-names of the surface zones for the init pacing of Mitchell Shaeffer (need for coupling)  Default value: []

    :param FileNodeFiber: Filename of the fiber par node of the mesh loaded (.bb file).  Default value: 

    :param nodeFibers: Fiber par node of the mesh loaded.  Default value: []

    :param FileFacetFiber: Filename of the fiber par facet of the mesh loaded (.tbb file).  Default value: 

    :param facetFibers: Fiber par facet of the mesh loaded.  Default value: []

    :param FileFacetBFiber: Filename of the fiber par facet of the mesh loaded, described in barycentric coordinates (.lbb file).  Default value: 

    :param facetBFibers: Fiber par facet of the mesh loaded, described in barycentric coordinates.  Default value: []

    :param FileTetraTensor: Filename of the tensor for each vertex on a tetra (.ttsr file)  Default value: 

    :param tetraTensor: tensor for each vertex on a tetra  Default value: []

    :param FileContractionParameters: Filename of the .txt containing the contraction parameters per zonename  Default value: 

    :param ContractionParameters: Parameter for linking to ContractionParameters from other components.  Default value: []

    :param InputContractionParameters: contraction parameter at each tetra  Default value: 

    :param FileTetraConductivity: FileTetraConductivity  Default value: 

    :param tetraConductivity:  Conductivity per tetra for MF electrical wave  Default value: []

    :param FileStiffnessParameters: Filename of the .txt containing the stiffness parameters per zonename  Default value: 

    :param StiffnessParameters: Parameter for linking to StiffnessParameters from other components.  Default value: []

    :param InputStiffnessParameters: stiffness parameter at each tetra  Default value: 

    :param ElectroFile: File with precomputed electrophysiology  Default value: 

    :param depoTimes: Times of depolarization per node  Default value: []

    :param APDTimes: Times of APD per node  Default value: []

    :param APDTimesZones: Times of APD per node  Default value: []

    :param APDTimesString: Times of APD per node  Default value: 

    :param APDTimesFile: Times of APD per node  Default value: 

    :param velocityFile: File with intial velocities  Default value: 

    :param velocities: initial velocities  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, polylines=polylines, edges=edges, triangles=triangles, quads=quads, polygons=polygons, highOrderEdgePositions=highOrderEdgePositions, highOrderTrianglePositions=highOrderTrianglePositions, highOrderQuadPositions=highOrderQuadPositions, tetrahedra=tetrahedra, hexahedra=hexahedra, pentahedra=pentahedra, highOrderTetrahedronPositions=highOrderTetrahedronPositions, highOrderHexahedronPositions=highOrderHexahedronPositions, pyramids=pyramids, normals=normals, edgesGroups=edgesGroups, trianglesGroups=trianglesGroups, quadsGroups=quadsGroups, polygonsGroups=polygonsGroups, tetrahedraGroups=tetrahedraGroups, hexahedraGroups=hexahedraGroups, pentahedraGroups=pentahedraGroups, pyramidsGroups=pyramidsGroups, flipNormals=flipNormals, triangulate=triangulate, createSubelements=createSubelements, onlyAttachedPoints=onlyAttachedPoints, translation=translation, rotation=rotation, scale3d=scale3d, transformation=transformation, createFibers=createFibers, outputNodeFibers=outputNodeFibers, outputTetraFibers=outputTetraFibers, TetraTriangle=TetraTriangle, unitTime=unitTime, TetraZoneName=TetraZoneName, PointZoneName=PointZoneName, withAHA=withAHA, TriZoneName=TriZoneName, AHAzoneName=AHAzoneName, startContraction=startContraction, angleEpi=angleEpi, angleEndo=angleEndo, CellTypes=CellTypes, numberOfZone=numberOfZone, m_zoneNames=m_zoneNames, m_zoneSizes=m_zoneSizes, numberOfSurfaceZone=numberOfSurfaceZone, m_surfaceZoneNames=m_surfaceZoneNames, m_surfaceZoneSizes=m_surfaceZoneSizes, MSinitSurfaceZoneNames=MSinitSurfaceZoneNames, FileNodeFiber=FileNodeFiber, nodeFibers=nodeFibers, FileFacetFiber=FileFacetFiber, facetFibers=facetFibers, FileFacetBFiber=FileFacetBFiber, facetBFibers=facetBFibers, FileTetraTensor=FileTetraTensor, tetraTensor=tetraTensor, FileContractionParameters=FileContractionParameters, ContractionParameters=ContractionParameters, InputContractionParameters=InputContractionParameters, FileTetraConductivity=FileTetraConductivity, tetraConductivity=tetraConductivity, FileStiffnessParameters=FileStiffnessParameters, StiffnessParameters=StiffnessParameters, InputStiffnessParameters=InputStiffnessParameters, ElectroFile=ElectroFile, depoTimes=depoTimes, APDTimes=APDTimes, APDTimesZones=APDTimesZones, APDTimesString=APDTimesString, APDTimesFile=APDTimesFile, velocityFile=velocityFile, velocities=velocities)
    return "CardiacVTKLoader", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MooneyRivlinForceField

.. autofunction:: MooneyRivlinForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MooneyRivlinForceField(self, **kwargs):
    """
    MooneyRivlin's Law for isotropic homogeneous materials



    """
    params = dict()
    return "MooneyRivlinForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component VisualManagerPass

.. autofunction:: VisualManagerPass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def VisualManagerPass(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, factor=None, renderToScreen=None, outputName=None, **kwargs):
    """
    VisualManagerPass


    :param name: object name  Default value: VisualManagerPass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param factor: set the resolution factor for the output pass. default value:1.0  Default value: 1.0

    :param renderToScreen: if true, this pass will be displayed on screen (only one renderPass in the scene must be defined as renderToScreen)  Default value: 0

    :param outputName: name the output texture  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, factor=factor, renderToScreen=renderToScreen, outputName=outputName)
    return "VisualManagerPass", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TransformEngine

.. autofunction:: TransformEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TransformEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, input_position=None, output_position=None, translation=None, rotation=None, quaternion=None, scale=None, inverse=None, **kwargs):
    """
    Transform position of 3d points
Transform position of dofs


    :param name: object name  Default value: TransformEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param input_position: input array of 3d points  Default value: []

    :param output_position: output array of 3d points  Default value: []

    :param translation: translation vector   Default value: [[0.0, 0.0, 0.0]]

    :param rotation: rotation vector   Default value: [[0.0, 0.0, 0.0]]

    :param quaternion: rotation quaternion   Default value: [[0.0, 0.0, 0.0, 1.0]]

    :param scale: scale factor  Default value: [[1.0, 1.0, 1.0]]

    :param inverse: true to apply inverse transformation  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, input_position=input_position, output_position=output_position, translation=translation, rotation=rotation, quaternion=quaternion, scale=scale, inverse=inverse)
    return "TransformEngine", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshGmshLoader

.. autofunction:: MeshGmshLoader

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshGmshLoader(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, polylines=None, edges=None, triangles=None, quads=None, polygons=None, highOrderEdgePositions=None, highOrderTrianglePositions=None, highOrderQuadPositions=None, tetrahedra=None, hexahedra=None, pentahedra=None, highOrderTetrahedronPositions=None, highOrderHexahedronPositions=None, pyramids=None, normals=None, edgesGroups=None, trianglesGroups=None, quadsGroups=None, polygonsGroups=None, tetrahedraGroups=None, hexahedraGroups=None, pentahedraGroups=None, pyramidsGroups=None, flipNormals=None, triangulate=None, createSubelements=None, onlyAttachedPoints=None, translation=None, rotation=None, scale3d=None, transformation=None, **kwargs):
    """
    Specific mesh loader for Gmsh file format.


    :param name: object name  Default value: MeshGmshLoader

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Invalid

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the object  Default value: 

    :param position: Vertices of the mesh loaded  Default value: []

    :param polylines: Polylines of the mesh loaded  Default value: []

    :param edges: Edges of the mesh loaded  Default value: []

    :param triangles: Triangles of the mesh loaded  Default value: []

    :param quads: Quads of the mesh loaded  Default value: []

    :param polygons: Polygons of the mesh loaded  Default value: []

    :param highOrderEdgePositions: High order edge points of the mesh loaded  Default value: []

    :param highOrderTrianglePositions: High order triangle points of the mesh loaded  Default value: []

    :param highOrderQuadPositions: High order quad points of the mesh loaded  Default value: []

    :param tetrahedra: Tetrahedra of the mesh loaded  Default value: []

    :param hexahedra: Hexahedra of the mesh loaded  Default value: []

    :param pentahedra: Pentahedra of the mesh loaded  Default value: []

    :param highOrderTetrahedronPositions: High order tetrahedron points of the mesh loaded  Default value: []

    :param highOrderHexahedronPositions: High order hexahedron points of the mesh loaded  Default value: []

    :param pyramids: Pyramids of the mesh loaded  Default value: []

    :param normals: Normals of the mesh loaded  Default value: []

    :param edgesGroups: Groups of Edges  Default value: 

    :param trianglesGroups: Groups of Triangles  Default value: 

    :param quadsGroups: Groups of Quads  Default value: 

    :param polygonsGroups: Groups of Polygons  Default value: 

    :param tetrahedraGroups: Groups of Tetrahedra  Default value: 

    :param hexahedraGroups: Groups of Hexahedra  Default value: 

    :param pentahedraGroups: Groups of Pentahedra  Default value: 

    :param pyramidsGroups: Groups of Pyramids  Default value: 

    :param flipNormals: Flip Normals  Default value: 0

    :param triangulate: Divide all polygons into triangles  Default value: 0

    :param createSubelements: Divide all n-D elements into their (n-1)-D boundary elements (e.g. tetrahedra to triangles)  Default value: 0

    :param onlyAttachedPoints: Only keep points attached to elements of the mesh  Default value: 0

    :param translation: Translation of the DOFs  Default value: [[0.0, 0.0, 0.0]]

    :param rotation: Rotation of the DOFs  Default value: [[0.0, 0.0, 0.0]]

    :param scale3d: Scale of the DOFs in 3 dimensions  Default value: [[1.0, 1.0, 1.0]]

    :param transformation: 4x4 Homogeneous matrix to transform the DOFs (when present replace any)  Default value: [[1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, polylines=polylines, edges=edges, triangles=triangles, quads=quads, polygons=polygons, highOrderEdgePositions=highOrderEdgePositions, highOrderTrianglePositions=highOrderTrianglePositions, highOrderQuadPositions=highOrderQuadPositions, tetrahedra=tetrahedra, hexahedra=hexahedra, pentahedra=pentahedra, highOrderTetrahedronPositions=highOrderTetrahedronPositions, highOrderHexahedronPositions=highOrderHexahedronPositions, pyramids=pyramids, normals=normals, edgesGroups=edgesGroups, trianglesGroups=trianglesGroups, quadsGroups=quadsGroups, polygonsGroups=polygonsGroups, tetrahedraGroups=tetrahedraGroups, hexahedraGroups=hexahedraGroups, pentahedraGroups=pentahedraGroups, pyramidsGroups=pyramidsGroups, flipNormals=flipNormals, triangulate=triangulate, createSubelements=createSubelements, onlyAttachedPoints=onlyAttachedPoints, translation=translation, rotation=rotation, scale3d=scale3d, transformation=transformation)
    return "MeshGmshLoader", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component DiagonalMass

.. autofunction:: DiagonalMass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def DiagonalMass(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, separateGravity=None, rayleighMass=None, vertexMass=None, massDensity=None, totalMass=None, computeMassOnRest=None, showGravityCenter=None, showAxisSizeFactor=None, filename=None, **kwargs):
    """
    Define a specific mass for each particle


    :param name: object name  Default value: DiagonalMass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param separateGravity: add separately gravity to velocity computation  Default value: 0

    :param rayleighMass: Rayleigh damping - mass matrix coefficient  Default value: 0.0

    :param vertexMass: Specify a vector giving the mass of each vertex. 
If unspecified or wrongly set, the massDensity or totalMass information is used.  Default value: []

    :param massDensity: Specify one single real and positive value for the mass density. 
If unspecified or wrongly set, the totalMass information is used.  Default value: 1.0

    :param totalMass: Specify the total mass resulting from all particles. 
If unspecified or wrongly set, the default value is used: totalMass = 1.0  Default value: 1.0

    :param computeMassOnRest: If true, the mass of every element is computed based on the rest position rather than the position  Default value: 1

    :param showGravityCenter: Display the center of gravity of the system  Default value: 0

    :param showAxisSizeFactor: Factor length of the axis displayed (only used for rigids)  Default value: 1.0

    :param filename: Xsp3.0 file to specify the mass parameters  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, separateGravity=separateGravity, rayleighMass=rayleighMass, vertexMass=vertexMass, massDensity=massDensity, totalMass=totalMass, computeMassOnRest=computeMassOnRest, showGravityCenter=showGravityCenter, showAxisSizeFactor=showAxisSizeFactor, filename=filename)
    return "DiagonalMass", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ExtrudeQuadsAndGenerateHexas

.. autofunction:: ExtrudeQuadsAndGenerateHexas

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ExtrudeQuadsAndGenerateHexas(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isVisible=None, scale=None, thicknessIn=None, thicknessOut=None, numberOfSlices=None, surfaceVertices=None, surfaceQuads=None, extrudedVertices=None, extrudedSurfaceQuads=None, extrudedQuads=None, extrudedHexas=None, **kwargs):
    """
    This engine extrudes a quad-based surface into a set of hexahedral elements


    :param name: object name  Default value: ExtrudeQuadsAndGenerateHexas

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isVisible: is Visible ?  Default value: 1

    :param scale: Apply a scaling factor to the extruded mesh  Default value: [[1.0, 1.0, 1.0]]

    :param thicknessIn: Thickness of the extruded volume in the opposite direction of the normals  Default value: 0.0

    :param thicknessOut: Thickness of the extruded volume in the direction of the normals  Default value: 1.0

    :param numberOfSlices: Number of slices / steps in the extrusion  Default value: 1

    :param surfaceVertices: Position coordinates of the surface  Default value: []

    :param surfaceQuads: Indices of the quads of the surface to extrude  Default value: []

    :param extrudedVertices: Coordinates of the extruded vertices  Default value: []

    :param extrudedSurfaceQuads: List of new surface quads generated during the extrusion  Default value: []

    :param extrudedQuads: List of all quads generated during the extrusion  Default value: []

    :param extrudedHexas: List of hexahedra generated during the extrusion  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isVisible=isVisible, scale=scale, thicknessIn=thicknessIn, thicknessOut=thicknessOut, numberOfSlices=numberOfSlices, surfaceVertices=surfaceVertices, surfaceQuads=surfaceQuads, extrudedVertices=extrudedVertices, extrudedSurfaceQuads=extrudedSurfaceQuads, extrudedQuads=extrudedQuads, extrudedHexas=extrudedHexas)
    return "ExtrudeQuadsAndGenerateHexas", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglTexture2D

.. autofunction:: OglTexture2D

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglTexture2D(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, id=None, indexShader=None, filename=None, textureUnit=None, enabled=None, repeat=None, linearInterpolation=None, generateMipmaps=None, srgbColorspace=None, minLod=None, maxLod=None, proceduralTextureWidth=None, proceduralTextureHeight=None, proceduralTextureNbBits=None, proceduralTextureData=None, cubemapFilenamePosX=None, cubemapFilenamePosY=None, cubemapFilenamePosZ=None, cubemapFilenameNegX=None, cubemapFilenameNegY=None, cubemapFilenameNegZ=None, texture2DFilename=None, **kwargs):
    """
    OglTexture2D


    :param name: object name  Default value: OglTexture2D

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param id: Set an ID name  Default value: 

    :param indexShader: Set the index of the desired shader you want to apply this parameter  Default value: 0

    :param filename: Texture Filename  Default value: 

    :param textureUnit: Set the texture unit  Default value: 1

    :param enabled: enabled ?  Default value: 1

    :param repeat: Repeat Texture ?  Default value: 0

    :param linearInterpolation: Interpolate Texture ?  Default value: 1

    :param generateMipmaps: Generate mipmaps ?  Default value: 1

    :param srgbColorspace: SRGB colorspace ?  Default value: 0

    :param minLod: Minimum mipmap lod ?  Default value: -1000.0

    :param maxLod: Maximum mipmap lod ?  Default value: 1000.0

    :param proceduralTextureWidth: Width of procedural Texture  Default value: 0

    :param proceduralTextureHeight: Height of procedural Texture  Default value: 0

    :param proceduralTextureNbBits: Nb bits per color  Default value: 1

    :param proceduralTextureData: Data of procedural Texture   Default value: []

    :param cubemapFilenamePosX: Texture filename of positive-X cubemap face  Default value: 

    :param cubemapFilenamePosY: Texture filename of positive-Y cubemap face  Default value: 

    :param cubemapFilenamePosZ: Texture filename of positive-Z cubemap face  Default value: 

    :param cubemapFilenameNegX: Texture filename of negative-X cubemap face  Default value: 

    :param cubemapFilenameNegY: Texture filename of negative-Y cubemap face  Default value: 

    :param cubemapFilenameNegZ: Texture filename of negative-Z cubemap face  Default value: 

    :param texture2DFilename: Texture2D Filename  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, id=id, indexShader=indexShader, filename=filename, textureUnit=textureUnit, enabled=enabled, repeat=repeat, linearInterpolation=linearInterpolation, generateMipmaps=generateMipmaps, srgbColorspace=srgbColorspace, minLod=minLod, maxLod=maxLod, proceduralTextureWidth=proceduralTextureWidth, proceduralTextureHeight=proceduralTextureHeight, proceduralTextureNbBits=proceduralTextureNbBits, proceduralTextureData=proceduralTextureData, cubemapFilenamePosX=cubemapFilenamePosX, cubemapFilenamePosY=cubemapFilenamePosY, cubemapFilenamePosZ=cubemapFilenamePosZ, cubemapFilenameNegX=cubemapFilenameNegX, cubemapFilenameNegY=cubemapFilenameNegY, cubemapFilenameNegZ=cubemapFilenameNegZ, texture2DFilename=texture2DFilename)
    return "OglTexture2D", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component UncoupledConstraintCorrection

.. autofunction:: UncoupledConstraintCorrection

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def UncoupledConstraintCorrection(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, compliance=None, defaultCompliance=None, verbose=None, correctionVelocityFactor=None, correctionPositionFactor=None, useOdeSolverIntegrationFactors=None, **kwargs):
    """
    Component computing constraint forces within a simulated body using the compliance method.
Component computing contact forces within a simulated body using the compliance method.
Component computing contact forces within a simulated body using the compliance method.


    :param name: object name  Default value: UncoupledConstraintCorrection

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param compliance: compliance value on each dof. If Rigid compliance (7 values): 1st value for translations, 6 others for upper-triangular part of symmetric 3x3 rotation compliance matrix  Default value: []

    :param defaultCompliance: Default compliance value for new dof or if all should have the same (in which case compliance vector should be empty)  Default value: 1e-05

    :param verbose: Dump the constraint matrix at each iteration  Default value: 0

    :param correctionVelocityFactor: Factor applied to the constraint forces when correcting the velocities  Default value: 1.0

    :param correctionPositionFactor: Factor applied to the constraint forces when correcting the positions  Default value: 1.0

    :param useOdeSolverIntegrationFactors: Use odeSolver integration factors instead of correctionVelocityFactor and correctionPositionFactor  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, compliance=compliance, defaultCompliance=defaultCompliance, verbose=verbose, correctionVelocityFactor=correctionVelocityFactor, correctionPositionFactor=correctionPositionFactor, useOdeSolverIntegrationFactors=useOdeSolverIntegrationFactors)
    return "UncoupledConstraintCorrection", params



# -*- coding: utf-8 -*-


"""
Module Topology

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    SparseGridRamificationTopology

    RegularGridTopology

    SphereGridTopology

    CylinderGridTopology

    SparseGridTopology

    SparseGridMultipleTopology

    CubeTopology

    GridTopology

    MeshTopology

    SphereQuadTopology



Content:
========

.. automodule::

    SparseGridRamificationTopology

    RegularGridTopology

    SphereGridTopology

    CylinderGridTopology

    SparseGridTopology

    SparseGridMultipleTopology

    CubeTopology

    GridTopology

    MeshTopology

    SphereQuadTopology



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['SparseGridRamificationTopology', 'RegularGridTopology', 'SphereGridTopology', 'CylinderGridTopology', 'SparseGridTopology', 'SparseGridMultipleTopology', 'CubeTopology', 'GridTopology', 'MeshTopology', 'SphereQuadTopology']
class Topology:
    from .SparseGridRamificationTopology import SparseGridRamificationTopology
    from .RegularGridTopology import RegularGridTopology
    from .SphereGridTopology import SphereGridTopology
    from .CylinderGridTopology import CylinderGridTopology
    from .SparseGridTopology import SparseGridTopology
    from .SparseGridMultipleTopology import SparseGridMultipleTopology
    from .CubeTopology import CubeTopology
    from .GridTopology import GridTopology
    from .MeshTopology import MeshTopology
    from .SphereQuadTopology import SphereQuadTopology



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component RequiredPlugin

.. autofunction:: RequiredPlugin

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def RequiredPlugin(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, pluginName=None, suffixMap=None, stopAfterFirstNameFound=None, stopAfterFirstSuffixFound=None, requireOne=None, requireAll=None, **kwargs):
    """
    Load the required plugins


    :param name: object name  Default value: RequiredPlugin

    :param printLog: if true, emits extra messages at runtime.  Default value: 1

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param pluginName: plugin name (or several names if you need to load different plugins or a plugin with several alternate names)  Default value: [['RequiredPlugin']]

    :param suffixMap: standard->custom suffixes pairs (to be used if the plugin is compiled outside of Sofa with a non standard way of differenciating versions), using ! to represent empty suffix  Default value: []

    :param stopAfterFirstNameFound: Stop after the first plugin name that is loaded successfully  Default value: 0

    :param stopAfterFirstSuffixFound: For each plugin name, stop after the first suffix that is loaded successfully  Default value: 1

    :param requireOne: Display an error message if no plugin names were successfully loaded  Default value: 0

    :param requireAll: Display an error message if any plugin names failed to be loaded  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, pluginName=pluginName, suffixMap=suffixMap, stopAfterFirstNameFound=stopAfterFirstNameFound, stopAfterFirstSuffixFound=stopAfterFirstSuffixFound, requireOne=requireOne, requireAll=requireAll)
    return "RequiredPlugin", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component VisualStyle

.. autofunction:: VisualStyle

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def VisualStyle(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, displayFlags=None, **kwargs):
    """
    Edit the visual style.
 Allowed values for displayFlags data are a combination of the following:
showAll, hideAll,
    showVisual, hideVisual,
        showVisualModels, hideVisualModels,
    showBehavior, hideBehavior,
        showBehaviorModels, hideBehaviorModels,
        showForceFields, hideForceFields,
        showInteractionForceFields, hideInteractionForceFields
    showMapping, hideMapping
        showMappings, hideMappings
        showMechanicalMappings, hideMechanicalMappings
    showCollision, hideCollision
        showCollisionModels, hideCollisionModels
        showBoundingCollisionModels, hideBoundingCollisionModels
    showOptions hideOptions
        showRendering hideRendering
        showNormals hideNormals
        showWireframe hideWireframe


    :param name: object name  Default value: VisualStyle

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param displayFlags: Display Flags  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, displayFlags=displayFlags)
    return "VisualStyle", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BlenderExporter

.. autofunction:: BlenderExporter

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BlenderExporter(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, path=None, baseName=None, simulationType=None, step=None, nbPtsByHair=None, **kwargs):
    """
    Export the simulation result as blender point cache files


    :param name: object name  Default value: BlenderExporter

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param path: output path  Default value: 

    :param baseName: Base name for the output files  Default value: 

    :param simulationType: simulation type (0: soft body, 1: particles, 2:cloth, 3:hair)  Default value: 0

    :param step: save the  simulation result every step frames  Default value: 2

    :param nbPtsByHair: number of element by hair strand  Default value: 20


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, path=path, baseName=baseName, simulationType=simulationType, step=step, nbPtsByHair=nbPtsByHair)
    return "BlenderExporter", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TextureInterpolation

.. autofunction:: TextureInterpolation

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TextureInterpolation(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, input_states=None, input_coordinates=None, output_coordinates=None, scalarField=None, min_value=None, max_value=None, manual_scale=None, drawPotentiels=None, showIndicesScale=None, vertexPloted=None, graph=None, **kwargs):
    """
    Create texture coordinate for a given field


    :param name: object name  Default value: TextureInterpolation

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param input_states: input array of state values.  Default value: []

    :param input_coordinates: input array of coordinates values.  Default value: []

    :param output_coordinates: output array of texture coordinates.  Default value: []

    :param scalarField: To interpolate only the first dimension of input field (useful if this component need to be templated in higher dimension).  Default value: 1

    :param min_value: minimum value of state value for interpolation.  Default value: 0.0

    :param max_value: maximum value of state value for interpolation.  Default value: 0.0

    :param manual_scale: compute texture interpolation on manually scale defined above.  Default value: 0

    :param drawPotentiels: Debug: view state values.  Default value: 0

    :param showIndicesScale: Debug : scale of state values displayed.  Default value: 9.99999974738e-05

    :param vertexPloted: Vertex index of values display in graph for each iteration.  Default value: 0

    :param graph: Vertex state value per iteration  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, input_states=input_states, input_coordinates=input_coordinates, output_coordinates=output_coordinates, scalarField=scalarField, min_value=min_value, max_value=max_value, manual_scale=manual_scale, drawPotentiels=drawPotentiels, showIndicesScale=showIndicesScale, vertexPloted=vertexPloted, graph=graph)
    return "TextureInterpolation", params



import glob
import os
import re


indent = "    "  # base indent
SINDENT = indent  # margin left


def parse_sources(src_path):
    ls = glob.glob(os.path.join(src_path, "**", "CMakeLists.txt"), recursive=True)

    classes = dict()
    for f in ls:
        classes.update(getFilesFromCMakeLists(f))

    classes = remove_bad_files(classes)
    # print(classes)

    cleaned = {}
    for i, (k, v) in enumerate(classes.items()):
        cleaned[os.path.basename(k)] = {}
        for e in v:
            cleaned[os.path.basename(k)].update(find_initData(f"{k}.{e}"))
    # print(cleaned)

    content = "from sofacomponents.lib.base_component import sofa_component\n\n"
    content += "class BaseSofaComponents:\n"

    for cls, args in cleaned.items():
        content += build_func(cls, args)
    # print(content)

    fname = os.path.join(os.path.dirname(__file__), "generated_classes.py")
    with open(fname, "w") as f:
        f.write(content)


def remove_bad_files(classes):
    cp = dict(classes)

    def delete_if(k, v):
        bname = os.path.basename(k)
        a = len(v) == 1 or "_test" in bname or bname[:4] == "init"
        b = not os.path.isfile(f"{k}.{v[0]}")
        return a or b

    for k, v in classes.items():
        if delete_if(k, v):
            del cp[k]

    return cp


def find_initData(fname):
    try:
        with open(fname, "r") as f:
            lines = f.readlines()
    except:
        return {}
    good = {}
    for line in lines:
        if "initData" in line:
            try:
                idt, msg = extract_from_initData(line)
                if check_args(idt, msg):
                    good[idt] = msg
            except:
                pass
    return good


def check_args(k, v):
    if k == "":
        return False
    if " " in k:
        return False
    if k in ["global", "in", "from", "yield"]:
        return False
    return True


def extract_from_initData(line):
    line = line.replace('\\"', "")
    line = line.split('"')
    idt, msg = line[-4], line[-2]
    return idt, msg


def getFilesFromCMakeLists(fname):
    with open(fname, "r") as f:
        lines = f.readlines()
    d = os.path.dirname(fname)
    res = dict()
    for line in lines:
        p = re.match("(.+?)\\.(\\w+)$", line.strip())
        if p:
            if not "#" in p[1]:
                k = os.path.join(d, p[1])
                l = res.get(k, list())
                l.append(p[2])
                res[k] = l

    return res


def build_func(name, d):
    s = template__(name, _doc_string(name, d), _kwargs(d), _params(d))
    return s


def template__(func_name, doc_string, kwargs, kwargs_dict):
    s = f"{SINDENT}@sofa_component\n"
    args = ["self", "**kwargs"]
    if len(kwargs) > 0:
        args.insert(1, kwargs)

    s += f"{SINDENT}def {func_name}({', '.join(args)}):\n"
    s += f"{SINDENT}{doc_string}\n"
    s += f"{SINDENT}{kwargs_dict}\n"
    s += f'{SINDENT}{indent}return "{func_name}", params\n\n'
    return s


def _params(args):
    s = indent + f'params = dict({", ".join(map(lambda x: f"{x}={x}", args))})'
    if len(args) > 0:
        s += f"\n{SINDENT}{indent}params = {{k: v for k, v in params.items() if v is not None}}"
    return s


def _kwargs(args):
    return ", ".join(map(lambda x: f"{x}=None", args))


def _doc_string(func_desc, args):
    s = indent + f'"""\n'
    s += f"{SINDENT}{indent}{func_desc}\n"
    if len(args) > 0:
        # s += f"\n{indent}Parameters:\n"
        s += "\n"
        for k, v in args.items():
            s += f"{SINDENT}{indent}:param {k}: {v}\n"
    s += f'{SINDENT}{indent}"""'
    return s


if __name__ == "__main__":
    parse_sources("/media/gaetan/UbuntuHDD/sofa/src/v20.06")



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TrianglePressureForceField

.. autofunction:: TrianglePressureForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TrianglePressureForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, pressure=None, cauchyStress=None, triangleList=None, normal=None, dmin=None, dmax=None, showForces=None, useConstantForce=None, trianglePressureMap=None, **kwargs):
    """
    TrianglePressure


    :param name: object name  Default value: TrianglePressureForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param pressure: Pressure force per unit area  Default value: [[0.0, 0.0, 0.0]]

    :param cauchyStress: Cauchy Stress applied on the normal of each triangle  Default value: [ 0 0 0 , 0 0 0 , 0 0 0 ,]

    :param triangleList: Indices of triangles separated with commas where a pressure is applied  Default value: []

    :param normal: Normal direction for the plane selection of triangles  Default value: [[0.0, 0.0, 0.0]]

    :param dmin: Minimum distance from the origin along the normal direction  Default value: 0.0

    :param dmax: Maximum distance from the origin along the normal direction  Default value: 0.0

    :param showForces: draw triangles which have a given pressure  Default value: 0

    :param useConstantForce: applied force is computed as the the pressure vector times the area at rest  Default value: 1

    :param trianglePressureMap: map between edge indices and their pressure  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, pressure=pressure, cauchyStress=cauchyStress, triangleList=triangleList, normal=normal, dmin=dmin, dmax=dmax, showForces=showForces, useConstantForce=useConstantForce, trianglePressureMap=trianglePressureMap)
    return "TrianglePressureForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component NewmarkImplicitSolver

.. autofunction:: NewmarkImplicitSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def NewmarkImplicitSolver(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, rayleighStiffness=None, rayleighMass=None, vdamping=None, gamma=None, beta=None, threadSafeVisitor=None, **kwargs):
    """
    Implicit time integratorusing Newmark scheme


    :param name: object name  Default value: NewmarkImplicitSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param rayleighStiffness: Rayleigh damping coefficient related to stiffness  Default value: 0.0

    :param rayleighMass: Rayleigh damping coefficient related to mass  Default value: 0.0

    :param vdamping: Velocity decay coefficient (no decay if null)  Default value: 0.0

    :param gamma: Newmark scheme gamma coefficient  Default value: 0.5

    :param beta: Newmark scheme beta coefficient  Default value: 0.25

    :param threadSafeVisitor: If true, do not use realloc and free visitors in fwdInteractionForceField.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, rayleighStiffness=rayleighStiffness, rayleighMass=rayleighMass, vdamping=vdamping, gamma=gamma, beta=beta, threadSafeVisitor=threadSafeVisitor)
    return "NewmarkImplicitSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component LennardJonesForceField

.. autofunction:: LennardJonesForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def LennardJonesForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, aInit=None, alpha=None, beta=None, dmax=None, fmax=None, d0=None, p0=None, damping=None, **kwargs):
    """
    Lennard-Jones forces for fluids


    :param name: object name  Default value: LennardJonesForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param aInit: a for Gravitational FF which corresponds to G*m1*m2 alpha should be equal to 1 and beta to 0.  Default value: 0.0

    :param alpha: Alpha  Default value: 6.0

    :param beta: Beta  Default value: 12.0

    :param dmax: DMax  Default value: 2.0

    :param fmax: FMax  Default value: 1.0

    :param d0: d0  Default value: 1.0

    :param p0: p0  Default value: 1.0

    :param damping: Damping  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, aInit=aInit, alpha=alpha, beta=beta, dmax=dmax, fmax=fmax, d0=d0, p0=p0, damping=damping)
    return "LennardJonesForceField", params



# -*- coding: utf-8 -*-


"""
Module ContextObject

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    Gravity



Content:
========

.. automodule::

    Gravity



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['Gravity']
class ContextObject:
    from .Gravity import Gravity



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component NewProximityIntersection

.. autofunction:: NewProximityIntersection

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def NewProximityIntersection(self, alarmDistance=None, contactDistance=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, useLineLine=None, **kwargs):
    """
    Optimized Proximity Intersection based on Triangle-Triangle tests, ignoring Edge-Edge cases


    :param name: object name  Default value: NewProximityIntersection

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param alarmDistance: Proximity detection distance  Default value: 1.0

    :param contactDistance: Distance below which a contact is created  Default value: 0.5

    :param useLineLine: Line-line collision detection enabled  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, alarmDistance=alarmDistance, contactDistance=contactDistance, useLineLine=useLineLine)
    return "NewProximityIntersection", params



# -*- coding: utf-8 -*-


"""
Module Legacy

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    GearSpringForceField

    TriangleDeformationMapping

    VolumeMapping

    DeformableOnRigidFrameMapping

    VolumePreservationForceField

    SubsetMapping

    Tetra2TriangleTopologicalMapping

    TubularMapping

    PlasticStrainMapping

    LinearMapping

    AffineMass

    SimpleTesselatedTetraTopologicalMapping

    SpringForceField

    RepulsiveSpringForceField

    BarycentricMapping

    LCPForceFeedback

    Quad2TriangleTopologicalMapping

    Hexa2QuadTopologicalMapping

    InvariantMapping

    TetrahedronVolumeMapping

    StiffSpringForceField

    CorotationalStrainMapping

    StabilizedNeoHookeanForceField

    TriangleStrainAverageMapping

    FixedRotationConstraint

    NeoHookeanForceField

    SlidingConstraint

    Distances

    UniformConstraint

    IdentityMapping

    SubsetMultiMapping

    BeamLinearMapping

    DistanceFromTargetMapping

    Mesh2PointTopologicalMapping

    PrincipalStretchesMapping

    CenterPointTopologicalMapping

    SquareDistanceMapping

    DevAngleCollisionMonitor

    FixedTranslationConstraint

    SkinningMapping

    DistanceMultiMapping

    DistanceMapping

    AngularSpringForceField

    DevTensionMonitor

    CenterOfMassMapping

    BeamFEMForceField

    CorotationalMeshMapping

    MuscleMaterialForceField

    RegularGridSpringForceField

    Edge2QuadTopologicalMapping

    LineSetSkinningMapping

    PolynomialMaterialForceField

    VectorSpringForceField

    PythonMainScriptController

    SimpleTesselatedHexaTopologicalMapping

    PenalityContactForceField

    IdentityMultiMapping

    IdentityTopologicalMapping

    TendonMaterialForceField

    ContactListener

    OBBCollisionModel

    HookeOrthotropicForceField

    CenterOfMassMultiMapping

    OgdenForceField

    ProjectiveForceField

    SkeletalMotionConstraint

    RelativeStrainMapping

    CompareTopology

    Hexa2TetraTopologicalMapping

    Mesh2PointMechanicalMapping

    CenterOfMassMulti2Mapping

    StabilizedHookeForceField

    JointSpringForceField

    SimpleTesselatedTetraMechanicalMapping

    StopperConstraint

    QuadBendingSprings

    FrameSpringForceField

    HookeForceField

    GreenStrainMapping

    MeshSpringForceField

    HookeTransverseForceField

    RigidMapping

    MLSMapping

    LinearMultiMapping

    MooneyRivlinForceField

    LinearStrainMapping

    CauchyStrainMapping

    SubsetTopologicalMapping

    ArticulatedSystemMapping

    RigidRigidMapping

    TriangleBendingSprings

    UnilateralInteractionConstraint

    Triangle2EdgeTopologicalMapping

    RigidConstraint

    HEMLStVKForceField

    SquareMapping

    HexahedronCompositeFEMMapping



Content:
========

.. automodule::

    GearSpringForceField

    TriangleDeformationMapping

    VolumeMapping

    DeformableOnRigidFrameMapping

    VolumePreservationForceField

    SubsetMapping

    Tetra2TriangleTopologicalMapping

    TubularMapping

    PlasticStrainMapping

    LinearMapping

    AffineMass

    SimpleTesselatedTetraTopologicalMapping

    SpringForceField

    RepulsiveSpringForceField

    BarycentricMapping

    LCPForceFeedback

    Quad2TriangleTopologicalMapping

    Hexa2QuadTopologicalMapping

    InvariantMapping

    TetrahedronVolumeMapping

    StiffSpringForceField

    CorotationalStrainMapping

    StabilizedNeoHookeanForceField

    TriangleStrainAverageMapping

    FixedRotationConstraint

    NeoHookeanForceField

    SlidingConstraint

    Distances

    UniformConstraint

    IdentityMapping

    SubsetMultiMapping

    BeamLinearMapping

    DistanceFromTargetMapping

    Mesh2PointTopologicalMapping

    PrincipalStretchesMapping

    CenterPointTopologicalMapping

    SquareDistanceMapping

    DevAngleCollisionMonitor

    FixedTranslationConstraint

    SkinningMapping

    DistanceMultiMapping

    DistanceMapping

    AngularSpringForceField

    DevTensionMonitor

    CenterOfMassMapping

    BeamFEMForceField

    CorotationalMeshMapping

    MuscleMaterialForceField

    RegularGridSpringForceField

    Edge2QuadTopologicalMapping

    LineSetSkinningMapping

    PolynomialMaterialForceField

    VectorSpringForceField

    PythonMainScriptController

    SimpleTesselatedHexaTopologicalMapping

    PenalityContactForceField

    IdentityMultiMapping

    IdentityTopologicalMapping

    TendonMaterialForceField

    ContactListener

    OBBCollisionModel

    HookeOrthotropicForceField

    CenterOfMassMultiMapping

    OgdenForceField

    ProjectiveForceField

    SkeletalMotionConstraint

    RelativeStrainMapping

    CompareTopology

    Hexa2TetraTopologicalMapping

    Mesh2PointMechanicalMapping

    CenterOfMassMulti2Mapping

    StabilizedHookeForceField

    JointSpringForceField

    SimpleTesselatedTetraMechanicalMapping

    StopperConstraint

    QuadBendingSprings

    FrameSpringForceField

    HookeForceField

    GreenStrainMapping

    MeshSpringForceField

    HookeTransverseForceField

    RigidMapping

    MLSMapping

    LinearMultiMapping

    MooneyRivlinForceField

    LinearStrainMapping

    CauchyStrainMapping

    SubsetTopologicalMapping

    ArticulatedSystemMapping

    RigidRigidMapping

    TriangleBendingSprings

    UnilateralInteractionConstraint

    Triangle2EdgeTopologicalMapping

    RigidConstraint

    HEMLStVKForceField

    SquareMapping

    HexahedronCompositeFEMMapping



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['GearSpringForceField', 'TriangleDeformationMapping', 'VolumeMapping', 'DeformableOnRigidFrameMapping', 'VolumePreservationForceField', 'SubsetMapping', 'Tetra2TriangleTopologicalMapping', 'TubularMapping', 'PlasticStrainMapping', 'LinearMapping', 'AffineMass', 'SimpleTesselatedTetraTopologicalMapping', 'SpringForceField', 'RepulsiveSpringForceField', 'BarycentricMapping', 'LCPForceFeedback', 'Quad2TriangleTopologicalMapping', 'Hexa2QuadTopologicalMapping', 'InvariantMapping', 'TetrahedronVolumeMapping', 'StiffSpringForceField', 'CorotationalStrainMapping', 'StabilizedNeoHookeanForceField', 'TriangleStrainAverageMapping', 'FixedRotationConstraint', 'NeoHookeanForceField', 'SlidingConstraint', 'Distances', 'UniformConstraint', 'IdentityMapping', 'SubsetMultiMapping', 'BeamLinearMapping', 'DistanceFromTargetMapping', 'Mesh2PointTopologicalMapping', 'PrincipalStretchesMapping', 'CenterPointTopologicalMapping', 'SquareDistanceMapping', 'DevAngleCollisionMonitor', 'FixedTranslationConstraint', 'SkinningMapping', 'DistanceMultiMapping', 'DistanceMapping', 'AngularSpringForceField', 'DevTensionMonitor', 'CenterOfMassMapping', 'BeamFEMForceField', 'CorotationalMeshMapping', 'MuscleMaterialForceField', 'RegularGridSpringForceField', 'Edge2QuadTopologicalMapping', 'LineSetSkinningMapping', 'PolynomialMaterialForceField', 'VectorSpringForceField', 'PythonMainScriptController', 'SimpleTesselatedHexaTopologicalMapping', 'PenalityContactForceField', 'IdentityMultiMapping', 'IdentityTopologicalMapping', 'TendonMaterialForceField', 'ContactListener', 'OBBCollisionModel', 'HookeOrthotropicForceField', 'CenterOfMassMultiMapping', 'OgdenForceField', 'ProjectiveForceField', 'SkeletalMotionConstraint', 'RelativeStrainMapping', 'CompareTopology', 'Hexa2TetraTopologicalMapping', 'Mesh2PointMechanicalMapping', 'CenterOfMassMulti2Mapping', 'StabilizedHookeForceField', 'JointSpringForceField', 'SimpleTesselatedTetraMechanicalMapping', 'StopperConstraint', 'QuadBendingSprings', 'FrameSpringForceField', 'HookeForceField', 'GreenStrainMapping', 'MeshSpringForceField', 'HookeTransverseForceField', 'RigidMapping', 'MLSMapping', 'LinearMultiMapping', 'MooneyRivlinForceField', 'LinearStrainMapping', 'CauchyStrainMapping', 'SubsetTopologicalMapping', 'ArticulatedSystemMapping', 'RigidRigidMapping', 'TriangleBendingSprings', 'UnilateralInteractionConstraint', 'Triangle2EdgeTopologicalMapping', 'RigidConstraint', 'HEMLStVKForceField', 'SquareMapping', 'HexahedronCompositeFEMMapping']
class Legacy:
    from .GearSpringForceField import GearSpringForceField
    from .TriangleDeformationMapping import TriangleDeformationMapping
    from .VolumeMapping import VolumeMapping
    from .DeformableOnRigidFrameMapping import DeformableOnRigidFrameMapping
    from .VolumePreservationForceField import VolumePreservationForceField
    from .SubsetMapping import SubsetMapping
    from .Tetra2TriangleTopologicalMapping import Tetra2TriangleTopologicalMapping
    from .TubularMapping import TubularMapping
    from .PlasticStrainMapping import PlasticStrainMapping
    from .LinearMapping import LinearMapping
    from .AffineMass import AffineMass
    from .SimpleTesselatedTetraTopologicalMapping import SimpleTesselatedTetraTopologicalMapping
    from .SpringForceField import SpringForceField
    from .RepulsiveSpringForceField import RepulsiveSpringForceField
    from .BarycentricMapping import BarycentricMapping
    from .LCPForceFeedback import LCPForceFeedback
    from .Quad2TriangleTopologicalMapping import Quad2TriangleTopologicalMapping
    from .Hexa2QuadTopologicalMapping import Hexa2QuadTopologicalMapping
    from .InvariantMapping import InvariantMapping
    from .TetrahedronVolumeMapping import TetrahedronVolumeMapping
    from .StiffSpringForceField import StiffSpringForceField
    from .CorotationalStrainMapping import CorotationalStrainMapping
    from .StabilizedNeoHookeanForceField import StabilizedNeoHookeanForceField
    from .TriangleStrainAverageMapping import TriangleStrainAverageMapping
    from .FixedRotationConstraint import FixedRotationConstraint
    from .NeoHookeanForceField import NeoHookeanForceField
    from .SlidingConstraint import SlidingConstraint
    from .Distances import Distances
    from .UniformConstraint import UniformConstraint
    from .IdentityMapping import IdentityMapping
    from .SubsetMultiMapping import SubsetMultiMapping
    from .BeamLinearMapping import BeamLinearMapping
    from .DistanceFromTargetMapping import DistanceFromTargetMapping
    from .Mesh2PointTopologicalMapping import Mesh2PointTopologicalMapping
    from .PrincipalStretchesMapping import PrincipalStretchesMapping
    from .CenterPointTopologicalMapping import CenterPointTopologicalMapping
    from .SquareDistanceMapping import SquareDistanceMapping
    from .DevAngleCollisionMonitor import DevAngleCollisionMonitor
    from .FixedTranslationConstraint import FixedTranslationConstraint
    from .SkinningMapping import SkinningMapping
    from .DistanceMultiMapping import DistanceMultiMapping
    from .DistanceMapping import DistanceMapping
    from .AngularSpringForceField import AngularSpringForceField
    from .DevTensionMonitor import DevTensionMonitor
    from .CenterOfMassMapping import CenterOfMassMapping
    from .BeamFEMForceField import BeamFEMForceField
    from .CorotationalMeshMapping import CorotationalMeshMapping
    from .MuscleMaterialForceField import MuscleMaterialForceField
    from .RegularGridSpringForceField import RegularGridSpringForceField
    from .Edge2QuadTopologicalMapping import Edge2QuadTopologicalMapping
    from .LineSetSkinningMapping import LineSetSkinningMapping
    from .PolynomialMaterialForceField import PolynomialMaterialForceField
    from .VectorSpringForceField import VectorSpringForceField
    from .PythonMainScriptController import PythonMainScriptController
    from .SimpleTesselatedHexaTopologicalMapping import SimpleTesselatedHexaTopologicalMapping
    from .PenalityContactForceField import PenalityContactForceField
    from .IdentityMultiMapping import IdentityMultiMapping
    from .IdentityTopologicalMapping import IdentityTopologicalMapping
    from .TendonMaterialForceField import TendonMaterialForceField
    from .ContactListener import ContactListener
    from .OBBCollisionModel import OBBCollisionModel
    from .HookeOrthotropicForceField import HookeOrthotropicForceField
    from .CenterOfMassMultiMapping import CenterOfMassMultiMapping
    from .OgdenForceField import OgdenForceField
    from .ProjectiveForceField import ProjectiveForceField
    from .SkeletalMotionConstraint import SkeletalMotionConstraint
    from .RelativeStrainMapping import RelativeStrainMapping
    from .CompareTopology import CompareTopology
    from .Hexa2TetraTopologicalMapping import Hexa2TetraTopologicalMapping
    from .Mesh2PointMechanicalMapping import Mesh2PointMechanicalMapping
    from .CenterOfMassMulti2Mapping import CenterOfMassMulti2Mapping
    from .StabilizedHookeForceField import StabilizedHookeForceField
    from .JointSpringForceField import JointSpringForceField
    from .SimpleTesselatedTetraMechanicalMapping import SimpleTesselatedTetraMechanicalMapping
    from .StopperConstraint import StopperConstraint
    from .QuadBendingSprings import QuadBendingSprings
    from .FrameSpringForceField import FrameSpringForceField
    from .HookeForceField import HookeForceField
    from .GreenStrainMapping import GreenStrainMapping
    from .MeshSpringForceField import MeshSpringForceField
    from .HookeTransverseForceField import HookeTransverseForceField
    from .RigidMapping import RigidMapping
    from .MLSMapping import MLSMapping
    from .LinearMultiMapping import LinearMultiMapping
    from .MooneyRivlinForceField import MooneyRivlinForceField
    from .LinearStrainMapping import LinearStrainMapping
    from .CauchyStrainMapping import CauchyStrainMapping
    from .SubsetTopologicalMapping import SubsetTopologicalMapping
    from .ArticulatedSystemMapping import ArticulatedSystemMapping
    from .RigidRigidMapping import RigidRigidMapping
    from .TriangleBendingSprings import TriangleBendingSprings
    from .UnilateralInteractionConstraint import UnilateralInteractionConstraint
    from .Triangle2EdgeTopologicalMapping import Triangle2EdgeTopologicalMapping
    from .RigidConstraint import RigidConstraint
    from .HEMLStVKForceField import HEMLStVKForceField
    from .SquareMapping import SquareMapping
    from .HexahedronCompositeFEMMapping import HexahedronCompositeFEMMapping



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MLSMapping

.. autofunction:: MLSMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MLSMapping(self, **kwargs):
    """
    Map child positions using generalized moving least squares.
Map child positions using moving least squares.
Map child positions using generalized moving least squares.
Map child positions using generalized moving least squares.



    """
    params = dict()
    return "MLSMapping", params



# -*- coding: utf-8 -*-


"""
Module Mapping

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    VoidMapping



Content:
========

.. automodule:: VoidMapping
    :members:




Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['VoidMapping']
class Mapping:
    from .VoidMapping import VoidMapping



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component VolumeRegional

.. autofunction:: VolumeRegional

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def VolumeRegional(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, meshA=None, observation=None, sizemin=None, exception=None, volume=None, file=None, **kwargs):
    """
    PressureConstraint's law in Tetrahedral finite elements


    :param name: object name  Default value: VolumeRegional

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param meshA: give mesh with AHA surf zones  Default value: 

    :param observation: give 0 for LV_endo, 1 for LVepi, 2 for LV, 3 for RV, 4 for Total  Default value: 0

    :param sizemin: number of triangles minumum per zones  Default value: 0

    :param exception: exception  Default value: 0

    :param volume: ..  Default value: []

    :param file: file  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, meshA=meshA, observation=observation, sizemin=sizemin, exception=exception, volume=volume, file=file)
    return "VolumeRegional", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshExporter

.. autofunction:: MeshExporter

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshExporter(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, saveMesh=None, filename=None, saveFibers=None, **kwargs):
    """
    Export topology and positions into file.   
Supported format are:   
- vtkxml  
- vtk  
- netgen  
- teten  
- gmsh  

Topology exporter


    :param name: object name  Default value: MeshExporter

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param saveMesh: if true save mesh  Default value: 0

    :param filename: output file name. Extension available are atr3D or atet3D  Default value: 

    :param saveFibers: if true save fibers. In the same name as mesh file, with the extension lbb  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, saveMesh=saveMesh, filename=filename, saveFibers=saveFibers)
    return "MeshExporter", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component UniformConstraint

.. autofunction:: UniformConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def UniformConstraint(self, **kwargs):
    """
    A constraint equation applied on all dofs.



    """
    params = dict()
    return "UniformConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component UniformMass

.. autofunction:: UniformMass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def UniformMass(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, separateGravity=None, rayleighMass=None, vertexMass=None, totalMass=None, filename=None, showGravityCenter=None, showAxisSizeFactor=None, compute_mapping_inertia=None, showInitialCenterOfGravity=None, showX0=None, localRange=None, indices=None, handleTopologicalChanges=None, preserveTotalMass=None, **kwargs):
    """
    Define the same mass for all the particles
Define the same mass for all the particles
Define the same mass for all the particles


    :param name: object name  Default value: UniformMass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param separateGravity: add separately gravity to velocity computation  Default value: 0

    :param rayleighMass: Rayleigh damping - mass matrix coefficient  Default value: 0.0

    :param vertexMass: Specify one single, positive, real value for the mass of each particle. 
If unspecified or wrongly set, the totalMass information is used.  Default value: 1.0

    :param totalMass: Specify the total mass resulting from all particles. 
If unspecified or wrongly set, the default value is used: totalMass = 1.0  Default value: 1.0

    :param filename: File storing the mass parameters [rigid objects only].  Default value: unused

    :param showGravityCenter: display the center of gravity of the system  Default value: 0

    :param showAxisSizeFactor: factor length of the axis displayed (only used for rigids)  Default value: 1.0

    :param compute_mapping_inertia: to be used if the mass is placed under a mapping  Default value: 0

    :param showInitialCenterOfGravity: display the initial center of gravity of the system  Default value: 0

    :param showX0: display the rest positions  Default value: 0

    :param localRange: optional range of local DOF indices. 
Any computation involving only indices outside of this range 
are discarded (useful for parallelization using mesh partitionning)  Default value: [[-1, -1]]

    :param indices: optional local DOF indices. Any computation involving only indices outside of this list are discarded  Default value: []

    :param handleTopologicalChanges: The mass and totalMass are recomputed on particles add/remove.  Default value: 0

    :param preserveTotalMass: Prevent totalMass from decreasing when removing particles.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, separateGravity=separateGravity, rayleighMass=rayleighMass, vertexMass=vertexMass, totalMass=totalMass, filename=filename, showGravityCenter=showGravityCenter, showAxisSizeFactor=showAxisSizeFactor, compute_mapping_inertia=compute_mapping_inertia, showInitialCenterOfGravity=showInitialCenterOfGravity, showX0=showX0, localRange=localRange, indices=indices, handleTopologicalChanges=handleTopologicalChanges, preserveTotalMass=preserveTotalMass)
    return "UniformMass", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CostaForceField

.. autofunction:: CostaForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CostaForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, matrixRegularization=None, tensorDirections=None, fiberDirections=None, ParameterSet=None, tetrahedronInfo=None, edgeInfo=None, file=None, **kwargs):
    """
    Costa's law in Tetrahedral finite elements


    :param name: object name  Default value: CostaForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param matrixRegularization: Regularization of the Stiffness Matrix (true or false)  Default value: 0

    :param tensorDirections:  file with DTI tensor at each tetra  Default value: []

    :param fiberDirections:  file with fibers at each tetra  Default value: []

    :param ParameterSet: The global parameters specifying the material  Default value: []

    :param tetrahedronInfo: Data to handle topology on tetrahedra  Default value: 

    :param edgeInfo: Data to handle topology on edges  Default value: 

    :param file: File where to store the Jacobian  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, matrixRegularization=matrixRegularization, tensorDirections=tensorDirections, fiberDirections=fiberDirections, ParameterSet=ParameterSet, tetrahedronInfo=tetrahedronInfo, edgeInfo=edgeInfo, file=file)
    return "CostaForceField", params



import functools


def sofa_component(func):
    @functools.wraps(func)
    def wrapper_sofa_component(*args, **kwargs):
        defaults = dict(args[0]._defaults) if len(args)>0 else dict()
        infos = func(*args, **kwargs)
        name, params = infos if len(infos) == 2 else (infos, dict())
        params = {k: v for k, v in params.items() if v is not None}
        defaults.update(params)
        defaults.update(kwargs)
        return name, defaults

    return wrapper_sofa_component



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshBarycentricMapperEngine

.. autofunction:: MeshBarycentricMapperEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshBarycentricMapperEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, inputPositions=None, mappedPointPositions=None, barycentricPositions=None, tableElements=None, computeLinearInterpolation=None, linearInterpolationIndices=None, linearInterpolationValues=None, **kwargs):
    """
    This class maps a set of points in a topological model and provide barycentric coordinates


    :param name: object name  Default value: MeshBarycentricMapperEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param inputPositions: Initial positions of the master points  Default value: []

    :param mappedPointPositions: Initial positions of the mapped points  Default value: []

    :param barycentricPositions: Output : Barycentric positions of the mapped points  Default value: []

    :param tableElements: Output : Table that provides the element index to which each input point belongs  Default value: []

    :param computeLinearInterpolation: if true, computes a linear interpolation (debug)  Default value: 0

    :param linearInterpolationIndices: Indices of a linear interpolation  Default value: []

    :param linearInterpolationValues: Values of a linear interpolation  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, inputPositions=inputPositions, mappedPointPositions=mappedPointPositions, barycentricPositions=barycentricPositions, tableElements=tableElements, computeLinearInterpolation=computeLinearInterpolation, linearInterpolationIndices=linearInterpolationIndices, linearInterpolationValues=linearInterpolationValues)
    return "MeshBarycentricMapperEngine", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MechanicalObject

.. autofunction:: MechanicalObject

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MechanicalObject(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, velocity=None, force=None, rest_position=None, externalForce=None, derivX=None, free_position=None, free_velocity=None, constraint=None, mappingJacobian=None, reset_position=None, reset_velocity=None, restScale=None, useTopology=None, showObject=None, showObjectScale=None, showIndices=None, showIndicesScale=None, showVectors=None, showVectorsScale=None, drawMode=None, showColor=None, translation=None, rotation=None, scale3d=None, translation2=None, rotation2=None, size=None, reserve=None, **kwargs):
    """
    mechanical state vectors
mechanical state vectors
Mechanical state vectors
mechanical state vectors
mechanical state vectors


    :param name: object name  Default value: MechanicalObject

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position: position coordinates of the degrees of freedom  Default value: [[0.0, 0.0, 0.0]]

    :param velocity: velocity coordinates of the degrees of freedom  Default value: [[0.0, 0.0, 0.0]]

    :param force: force vector of the degrees of freedom  Default value: [[0.0, 0.0, 0.0]]

    :param rest_position: rest position coordinates of the degrees of freedom  Default value: []

    :param externalForce: externalForces vector of the degrees of freedom  Default value: [[0.0, 0.0, 0.0]]

    :param derivX: dx vector of the degrees of freedom  Default value: []

    :param free_position: free position coordinates of the degrees of freedom  Default value: []

    :param free_velocity: free velocity coordinates of the degrees of freedom  Default value: []

    :param constraint: constraints applied to the degrees of freedom  Default value: 

    :param mappingJacobian: mappingJacobian applied to the degrees of freedom  Default value: 

    :param reset_position: reset position coordinates of the degrees of freedom  Default value: []

    :param reset_velocity: reset velocity coordinates of the degrees of freedom  Default value: []

    :param restScale: optional scaling of rest position coordinates (to simulated pre-existing internal tension).(default = 1.0)  Default value: 1.0

    :param useTopology: Shall this object rely on any active topology to initialize its size and positions  Default value: 1

    :param showObject: Show objects. (default=false)  Default value: 0

    :param showObjectScale: Scale for object display. (default=0.1)  Default value: 0.10000000149

    :param showIndices: Show indices. (default=false)  Default value: 0

    :param showIndicesScale: Scale for indices display. (default=0.02)  Default value: 0.019999999553

    :param showVectors: Show velocity. (default=false)  Default value: 0

    :param showVectorsScale: Scale for vectors display. (default=0.0001)  Default value: 9.99999974738e-05

    :param drawMode: The way vectors will be drawn:
- 0: Line
- 1:Cylinder
- 2: Arrow.

The DOFS will be drawn:
- 0: point
- >1: sphere. (default=0)  Default value: 0

    :param showColor: Color for object display. (default=[1 1 1 1])  Default value: [[1.0, 1.0, 1.0, 1.0]]

    :param translation: Translation of the DOFs  Default value: [[0.0, 0.0, 0.0]]

    :param rotation: Rotation of the DOFs  Default value: [[0.0, 0.0, 0.0]]

    :param scale3d: Scale of the DOFs in 3 dimensions  Default value: [[1.0, 1.0, 1.0]]

    :param translation2: Translation of the DOFs, applied after the rest position has been computed  Default value: [[0.0, 0.0, 0.0]]

    :param rotation2: Rotation of the DOFs, applied the after the rest position has been computed  Default value: [[0.0, 0.0, 0.0]]

    :param size: Size of the vectors  Default value: 1

    :param reserve: Size to reserve when creating vectors. (default=0)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, velocity=velocity, force=force, rest_position=rest_position, externalForce=externalForce, derivX=derivX, free_position=free_position, free_velocity=free_velocity, constraint=constraint, mappingJacobian=mappingJacobian, reset_position=reset_position, reset_velocity=reset_velocity, restScale=restScale, useTopology=useTopology, showObject=showObject, showObjectScale=showObjectScale, showIndices=showIndices, showIndicesScale=showIndicesScale, showVectors=showVectors, showVectorsScale=showVectorsScale, drawMode=drawMode, showColor=showColor, translation=translation, rotation=rotation, scale3d=scale3d, translation2=translation2, rotation2=rotation2, size=size, reserve=reserve)
    return "MechanicalObject", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component FlexibleCorotationalFEMForceField

.. autofunction:: FlexibleCorotationalFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def FlexibleCorotationalFEMForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, nbRef=None, position=None, tolerance=None, method=None, order=None, youngModulus=None, poissonRatio=None, viscosity=None, geometricStiffness=None, **kwargs):
    """
    Flexible Tetrahedral finite elements


    :param name: object name  Default value: FlexibleCorotationalFEMForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param nbRef: maximum number of parents per child  Default value: 4

    :param position: position of parent nodes  Default value: []

    :param tolerance: minimum weight (allows for mapping outside elements)  Default value: -1.0

    :param method: Decomposition method  Default value: svd

    :param order: Order of quadrature method  Default value: 1

    :param youngModulus: Young Modulus  Default value: 5000.0

    :param poissonRatio: Poisson Ratio  Default value: 0.0

    :param viscosity: Viscosity (stress/strainRate)  Default value: 0.0

    :param geometricStiffness: Should geometricStiffness be considered?  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, nbRef=nbRef, position=position, tolerance=tolerance, method=method, order=order, youngModulus=youngModulus, poissonRatio=poissonRatio, viscosity=viscosity, geometricStiffness=geometricStiffness)
    return "FlexibleCorotationalFEMForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GeometryMonitor

.. autofunction:: GeometryMonitor

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GeometryMonitor(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, handleEventTriggersUpdate=None, file=None, PointMitralExtremal=None, PointTricuspidExtremal=None, PointTopSeptum=None, PointApexRV=None, PointApexLV=None, AxisHeart=None, AxisRings=None, AxisLV=None, AxisRV=None, BarycentreMesh=None, BarycentreTwoRings=None, BarycentreRingMitral=None, BarycentreRingTricuspid=None, BarycentreLVendo=None, **kwargs):
    """
    Control the degree of Bezier tetrahedra on AdaptiveBezierTetrahedronContainer


    :param name: object name  Default value: GeometryMonitor

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param handleEventTriggersUpdate: Event handling frequency controls the controller update frequency  Default value: 0

    :param file: file  Default value: 

    :param PointMitralExtremal: PointMitralExtremal  Default value: 0

    :param PointTricuspidExtremal: PointTricuspidExtremal  Default value: 0

    :param PointTopSeptum: PointTopSeptum  Default value: 0

    :param PointApexRV: PointApexRV  Default value: 0

    :param PointApexLV: PointApexLV  Default value: 0

    :param AxisHeart: AxisHeart  Default value: [[0.0, 0.0, 0.0]]

    :param AxisRings: AxisRings  Default value: [[0.0, 0.0, 0.0]]

    :param AxisLV: AxisLV  Default value: [[0.0, 0.0, 0.0]]

    :param AxisRV: AxisRV  Default value: [[0.0, 0.0, 0.0]]

    :param BarycentreMesh: BarycentreMesh  Default value: [[0.0, 0.0, 0.0]]

    :param BarycentreTwoRings: BarycentreTwoRings  Default value: [[0.0, 0.0, 0.0]]

    :param BarycentreRingMitral: BarycentreRingMitral  Default value: [[0.0, 0.0, 0.0]]

    :param BarycentreRingTricuspid: BarycentreRingTricuspid  Default value: [[0.0, 0.0, 0.0]]

    :param BarycentreLVendo: BarycentreLVendo  Default value: [[0.0, 0.0, 0.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, handleEventTriggersUpdate=handleEventTriggersUpdate, file=file, PointMitralExtremal=PointMitralExtremal, PointTricuspidExtremal=PointTricuspidExtremal, PointTopSeptum=PointTopSeptum, PointApexRV=PointApexRV, PointApexLV=PointApexLV, AxisHeart=AxisHeart, AxisRings=AxisRings, AxisLV=AxisLV, AxisRV=AxisRV, BarycentreMesh=BarycentreMesh, BarycentreTwoRings=BarycentreTwoRings, BarycentreRingMitral=BarycentreRingMitral, BarycentreRingTricuspid=BarycentreRingTricuspid, BarycentreLVendo=BarycentreLVendo)
    return "GeometryMonitor", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TriangularFEMForceField

.. autofunction:: TriangularFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TriangularFEMForceField(self, poissonRatio=None, youngModulus=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, triangleInfo=None, vertexInfo=None, edgeInfo=None, method=None, damping=None, rotatedInitialElements=None, initialTransformation=None, fracturable=None, hosfordExponant=None, criteriaValue=None, showStressValue=None, showStressVector=None, showFracturableTriangles=None, computePrincipalStress=None, **kwargs):
    """
    Corotational Triangular finite elements


    :param name: object name  Default value: TriangularFEMForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param triangleInfo: Internal triangle data  Default value: 

    :param vertexInfo: Internal point data  Default value: 

    :param edgeInfo: Internal edge data  Default value: 

    :param method: large: large displacements, small: small displacements  Default value: large

    :param poissonRatio: Poisson ratio in Hooke's law (vector)  Default value: [[0.45]]

    :param youngModulus: Young modulus in Hooke's law (vector)  Default value: [[1000.0]]

    :param damping: Ratio damping/stiffness  Default value: 0.0

    :param rotatedInitialElements: Flag activating rendering of stress directions within each triangle  Default value: []

    :param initialTransformation: Flag activating rendering of stress directions within each triangle  Default value: []

    :param fracturable: the forcefield computes the next fracturable Edge  Default value: 0

    :param hosfordExponant: Exponant in the Hosford yield criteria  Default value: 1.0

    :param criteriaValue: Fracturable threshold used to draw fracturable triangles  Default value: 1e+15

    :param showStressValue: Flag activating rendering of stress values as a color in each triangle  Default value: 0

    :param showStressVector: Flag activating rendering of stress directions within each triangle  Default value: 0

    :param showFracturableTriangles: Flag activating rendering of triangles to fracture  Default value: 0

    :param computePrincipalStress: Compute principal stress for each triangle  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, triangleInfo=triangleInfo, vertexInfo=vertexInfo, edgeInfo=edgeInfo, method=method, poissonRatio=poissonRatio, youngModulus=youngModulus, damping=damping, rotatedInitialElements=rotatedInitialElements, initialTransformation=initialTransformation, fracturable=fracturable, hosfordExponant=hosfordExponant, criteriaValue=criteriaValue, showStressValue=showStressValue, showStressVector=showStressVector, showFracturableTriangles=showFracturableTriangles, computePrincipalStress=computePrincipalStress)
    return "TriangularFEMForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TetrahedralCorotationalFEMForceField

.. autofunction:: TetrahedralCorotationalFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TetrahedralCorotationalFEMForceField(self, poissonRatio=None, youngModulus=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, tetrahedronInfo=None, method=None, localStiffnessFactor=None, updateStiffnessMatrix=None, computeGlobalMatrix=None, drawing=None, drawColor1=None, drawColor2=None, drawColor3=None, drawColor4=None, **kwargs):
    """
    Corotational FEM Tetrahedral finite elements


    :param name: object name  Default value: TetrahedralCorotationalFEMForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param tetrahedronInfo: Internal tetrahedron data  Default value: 

    :param method: "small", "large" (by QR) or "polar" displacements  Default value: large

    :param poissonRatio: FEM Poisson Ratio  Default value: 0.449999988079

    :param youngModulus: FEM Young Modulus  Default value: 5000.0

    :param localStiffnessFactor: Allow specification of different stiffness per element. If there are N element and M values are specified, the youngModulus factor for element i would be localStiffnessFactor[i*M/N]  Default value: []

    :param updateStiffnessMatrix: (No help available)  Default value: 0

    :param computeGlobalMatrix: (No help available)  Default value: 0

    :param drawing:  draw the forcefield if true  Default value: 1

    :param drawColor1:  draw color for faces 1  Default value: [[0.0, 0.0, 1.0, 1.0]]

    :param drawColor2:  draw color for faces 2  Default value: [[0.0, 0.5, 1.0, 1.0]]

    :param drawColor3:  draw color for faces 3  Default value: [[0.0, 1.0, 1.0, 1.0]]

    :param drawColor4:  draw color for faces 4  Default value: [[0.5, 1.0, 1.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, tetrahedronInfo=tetrahedronInfo, method=method, poissonRatio=poissonRatio, youngModulus=youngModulus, localStiffnessFactor=localStiffnessFactor, updateStiffnessMatrix=updateStiffnessMatrix, computeGlobalMatrix=computeGlobalMatrix, drawing=drawing, drawColor1=drawColor1, drawColor2=drawColor2, drawColor3=drawColor3, drawColor4=drawColor4)
    return "TetrahedralCorotationalFEMForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ProjectiveTransformEngine

.. autofunction:: ProjectiveTransformEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ProjectiveTransformEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, input_position=None, output_position=None, proj_mat=None, focal_distance=None, **kwargs):
    """
    Project the position of 3d points onto a plane according to a projection matrix


    :param name: object name  Default value: ProjectiveTransformEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param input_position: input array of 3d points  Default value: []

    :param output_position: output array of projected 3d points  Default value: []

    :param proj_mat: projection matrix   Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param focal_distance: focal distance   Default value: 1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, input_position=input_position, output_position=output_position, proj_mat=proj_mat, focal_distance=focal_distance)
    return "ProjectiveTransformEngine", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component DistanceLMConstraint

.. autofunction:: DistanceLMConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def DistanceLMConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, constraintIndex=None, object1=None, object2=None, vecConstraint=None, **kwargs):
    """
    Maintain constant the length of some edges of a pair of objects


    :param name: object name  Default value: DistanceLMConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param constraintIndex: Constraint index (first index in the right hand term resolution vector)  Default value: 0

    :param object1: First Object to constrain  Default value: 

    :param object2: Second Object to constrain  Default value: 

    :param vecConstraint: List of the edges to constrain  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, constraintIndex=constraintIndex, object1=object1, object2=object2, vecConstraint=vecConstraint)
    return "DistanceLMConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CubeTopology

.. autofunction:: CubeTopology

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CubeTopology(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, edges=None, triangles=None, quads=None, tetrahedra=None, hexahedra=None, uv=None, drawEdges=None, drawTriangles=None, drawQuads=None, drawTetrahedra=None, drawHexahedra=None, nx=None, ny=None, nz=None, internalPoints=None, splitNormals=None, min=None, max=None, **kwargs):
    """
    Surface of a cube in 3D


    :param name: object name  Default value: CubeTopology

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the mesh  Default value: 

    :param position: List of point positions  Default value: []

    :param edges: List of edge indices  Default value: []

    :param triangles: List of triangle indices  Default value: []

    :param quads: List of quad indices  Default value: []

    :param tetrahedra: List of tetrahedron indices  Default value: []

    :param hexahedra: List of hexahedron indices  Default value: []

    :param uv: List of uv coordinates  Default value: []

    :param drawEdges: if true, draw the topology Edges  Default value: 0

    :param drawTriangles: if true, draw the topology Triangles  Default value: 0

    :param drawQuads: if true, draw the topology Quads  Default value: 0

    :param drawTetrahedra: if true, draw the topology Tetrahedra  Default value: 0

    :param drawHexahedra: if true, draw the topology hexahedra  Default value: 0

    :param nx: x grid resolution  Default value: 0

    :param ny: y grid resolution  Default value: 0

    :param nz: z grid resolution  Default value: 0

    :param internalPoints: include internal points (allow a one-to-one mapping between points from RegularGridTopology and CubeTopology)  Default value: 0

    :param splitNormals: split corner points to have planar normals  Default value: 0

    :param min: Min  Default value: [[0.0, 0.0, 0.0]]

    :param max: Max  Default value: [[1.0, 1.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, edges=edges, triangles=triangles, quads=quads, tetrahedra=tetrahedra, hexahedra=hexahedra, uv=uv, drawEdges=drawEdges, drawTriangles=drawTriangles, drawQuads=drawQuads, drawTetrahedra=drawTetrahedra, drawHexahedra=drawHexahedra, nx=nx, ny=ny, nz=nz, internalPoints=internalPoints, splitNormals=splitNormals, min=min, max=max)
    return "CubeTopology", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component FastTetrahedralCorotationalForceField

.. autofunction:: FastTetrahedralCorotationalForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def FastTetrahedralCorotationalForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, pointInfo=None, edgeInfo=None, tetrahedronInfo=None, method=None, poissonRatio=None, youngModulus=None, drawing=None, drawColor1=None, drawColor2=None, drawColor3=None, drawColor4=None, **kwargs):
    """
    Fast Corotational Tetrahedral Mesh


    :param name: object name  Default value: FastTetrahedralCorotationalForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param pointInfo: Internal point data  Default value: []

    :param edgeInfo: Internal edge data  Default value: []

    :param tetrahedronInfo: Internal tetrahedron data  Default value: 

    :param method:  method for rotation computation :"qr" (by QR) or "polar" or "polar2" or "none" (Linear elastic)   Default value: qr

    :param poissonRatio: Poisson ratio in Hooke's law  Default value: 0.3

    :param youngModulus: Young modulus in Hooke's law  Default value: 1000.0

    :param drawing:  draw the forcefield if true  Default value: 1

    :param drawColor1:  draw color for faces 1  Default value: [[0.0, 0.0, 1.0, 1.0]]

    :param drawColor2:  draw color for faces 2  Default value: [[0.0, 0.5, 1.0, 1.0]]

    :param drawColor3:  draw color for faces 3  Default value: [[0.0, 1.0, 1.0, 1.0]]

    :param drawColor4:  draw color for faces 4  Default value: [[0.5, 1.0, 1.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, pointInfo=pointInfo, edgeInfo=edgeInfo, tetrahedronInfo=tetrahedronInfo, method=method, poissonRatio=poissonRatio, youngModulus=youngModulus, drawing=drawing, drawColor1=drawColor1, drawColor2=drawColor2, drawColor3=drawColor3, drawColor4=drawColor4)
    return "FastTetrahedralCorotationalForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MergePoints

.. autofunction:: MergePoints

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MergePoints(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position1=None, position2=None, mappingX2=None, indices1=None, indices2=None, points=None, noUpdate=None, **kwargs):
    """
    Merge 2 cordinate vectors


    :param name: object name  Default value: MergePoints

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position1: position coordinates of the degrees of freedom of the first object  Default value: []

    :param position2: Rest position coordinates of the degrees of freedom of the second object  Default value: []

    :param mappingX2: Mapping of indices to inject position2 inside position1 vertex buffer  Default value: []

    :param indices1: Indices of the points of the first object  Default value: []

    :param indices2: Indices of the points of the second object  Default value: []

    :param points: position coordinates of the merge  Default value: []

    :param noUpdate: do not update the output at eacth time step (false)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position1=position1, position2=position2, mappingX2=mappingX2, indices1=indices1, indices2=indices2, points=points, noUpdate=noUpdate)
    return "MergePoints", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ClusteringEngine

.. autofunction:: ClusteringEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ClusteringEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, useTopo=None, radius=None, fixedRadius=None, number=None, fixedPosition=None, position=None, cluster=None, inFile=None, outFile=None, **kwargs):
    """
    Group points into overlapping clusters according to a user defined number of clusters and radius


    :param name: object name  Default value: ClusteringEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param useTopo: Use avalaible topology to compute neighborhood.  Default value: 1

    :param radius: Neighborhood range.  Default value: 1.0

    :param fixedRadius: Neighborhood range (for non mechanical particles).  Default value: 1.0

    :param number: Number of clusters (-1 means that all input points are selected).  Default value: -1

    :param fixedPosition: Input positions of fixed (non mechanical) particles.  Default value: []

    :param position: Input rest positions.  Default value: []

    :param cluster: Computed clusters.  Default value: []

    :param inFile: import precomputed clusters  Default value: 

    :param outFile: export clusters  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, useTopo=useTopo, radius=radius, fixedRadius=fixedRadius, number=number, fixedPosition=fixedPosition, position=position, cluster=cluster, inFile=inFile, outFile=outFile)
    return "ClusteringEngine", params



import sys
import os


class Node:
    def __init__(self, name="root", parent=None):
        self.name = name
        self.parent = parent
        self.children = []
        self.objects = []
        self._attrs = {}

    def child(self, name):
        self.children.append(Node(name, self))
        return self.children[-1]

    def add(self, *objs):
        for obj in objs:
            self.objects.append(obj)
        return self

    def __repr__(self):
        return self.printSelf()

    def printSelf(self, i=2, display_args=True):
        s = "{}\n".format(self.name)
        carret = u"\u2514"
        if sys.version_info[0] == 2:  # Python 2.7
            carret = carret.encode("utf-8")

        for o in self.objects:
            kwargs = ""
            if display_args:
                kwargs = " ({})".format(
                    ", ".join([k + "=" + str(v) for k, v in o[1].items()])
                )
            s += "{}{} {}{}\n".format(" " * i, carret, o[0], kwargs)

        for d in self.children:
            s += "{}{} {}\n".format(" " * i, carret, d.printSelf(i + 2, display_args))

        return s.rstrip()

    def write_graph_to(self, fname, display_args=False):
        with open(fname, "w") as f:
            f.write(self.printSelf(display_args=display_args))

    def dump_into(self, node):
        """ Direct use in a scene """
        createObject = getattr(node, "createObject")
        createChild = getattr(node, "createChild")

        for k, v in self._attrs.items():
            setattr(node, k, v)

        for obj in self.objects:
            createObject(obj[0], **obj[1])

        for d in self.children:
            child_node = createChild(d.name)
            d.dump_into(child_node)

    def write_scene_to(self, fname):
        temp = os.path.join(os.path.dirname(__file__), "lib", "template_scene.py")
        with open(temp, "r") as f:
            content = f.read()

        content = content.format(self.to_python())

        with open(fname, "w") as f:
            f.write(content)

    def to_python(self):
        """ Export the scene to file """
        s = []

        for k, v in self._attrs.items():
            s.append("{}.{} = {}".format(self.name, k, v))

        for o in self.objects:
            kwargs = [k + "=" + cc(v) for k, v in o[1].items()]
            s.append(
                "{}.createObject('{}', {})".format(self.name, o[0], ", ".join(kwargs))
            )

        for d in self.children:
            s.append("")
            s.append("# {}/{}".format(self.par(), d.name))
            s.append("{} = {}.createChild('{}')".format(d.name, self.name, d.name))
            s.append(d.to_python())

        return "\n        ".join(s)

    def attrs(self, **kwargs):
        self._attrs.update(kwargs)

    def par(self):
        if self.parent is not None:
            return "/".join([self.parent.par(), self.name])
        else:
            return self.name


def cc(v):
    return "'{}'".format(v) if type(v) is str else str(v)



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BilateralInteractionConstraint

.. autofunction:: BilateralInteractionConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BilateralInteractionConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, constraintIndex=None, endTime=None, first_point=None, second_point=None, rest_vector=None, numericalTolerance=None, activateAtIteration=None, merge=None, derivative=None, keepOrientationDifference=None, **kwargs):
    """
    TODO-BilateralInteractionConstraint


    :param name: object name  Default value: BilateralInteractionConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param constraintIndex: Constraint index (first index in the right hand term resolution vector)  Default value: 0

    :param endTime: The constraint stops acting after the given value.
Use a negative value for infinite constraints  Default value: -1.0

    :param first_point: index of the constraint on the first model  Default value: []

    :param second_point: index of the constraint on the second model  Default value: []

    :param rest_vector: Relative position to maintain between attached points (optional)  Default value: []

    :param numericalTolerance: a real value specifying the tolerance during the constraint solving. (optional, default=0.0001)  Default value: 0.0001

    :param activateAtIteration: activate constraint at specified interation (0 = always enabled, -1=disabled)  Default value: 0

    :param merge: TEST: merge the bilateral constraints in a unique constraint  Default value: 0

    :param derivative: TEST: derivative  Default value: 0

    :param keepOrientationDifference: keep the initial difference in orientation (only for rigids)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, constraintIndex=constraintIndex, endTime=endTime, first_point=first_point, second_point=second_point, rest_vector=rest_vector, numericalTolerance=numericalTolerance, activateAtIteration=activateAtIteration, merge=merge, derivative=derivative, keepOrientationDifference=keepOrientationDifference)
    return "BilateralInteractionConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TetrahedronFEMForceField

.. autofunction:: TetrahedronFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TetrahedronFEMForceField(self, poissonRatio=None, youngModulus=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, initialPoints=None, method=None, localStiffnessFactor=None, updateStiffnessMatrix=None, computeGlobalMatrix=None, plasticMaxThreshold=None, plasticYieldThreshold=None, plasticCreep=None, gatherPt=None, gatherBsize=None, drawHeterogeneousTetra=None, drawAsEdges=None, computeVonMisesStress=None, vonMisesPerElement=None, vonMisesPerNode=None, vonMisesStressColors=None, showStressColorMap=None, showStressAlpha=None, showVonMisesStressPerNode=None, updateStiffness=None, **kwargs):
    """
    Tetrahedral finite elements


    :param name: object name  Default value: TetrahedronFEMForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param initialPoints: Initial Position  Default value: []

    :param method: "small", "large" (by QR), "polar" or "svd" displacements  Default value: large

    :param poissonRatio: FEM Poisson Ratio [0,0.5[  Default value: 0.449999988079

    :param youngModulus: FEM Young Modulus  Default value: [[5000.0]]

    :param localStiffnessFactor: Allow specification of different stiffness per element. If there are N element and M values are specified, the youngModulus factor for element i would be localStiffnessFactor[i*M/N]  Default value: []

    :param updateStiffnessMatrix: (No help available)  Default value: 0

    :param computeGlobalMatrix: (No help available)  Default value: 0

    :param plasticMaxThreshold: Plastic Max Threshold (2-norm of the strain)  Default value: 0.0

    :param plasticYieldThreshold: Plastic Yield Threshold (2-norm of the strain)  Default value: 9.99999974738e-05

    :param plasticCreep: Plastic Creep Factor * dt [0,1]. Warning this factor depends on dt.  Default value: 0.899999976158

    :param gatherPt: number of dof accumulated per threads during the gather operation (Only use in GPU version)  Default value:  

    :param gatherBsize: number of dof accumulated per threads during the gather operation (Only use in GPU version)  Default value:  

    :param drawHeterogeneousTetra: Draw Heterogeneous Tetra in different color  Default value: 0

    :param drawAsEdges: Draw as edges instead of tetrahedra  Default value: 0

    :param computeVonMisesStress: compute and display von Mises stress: 0: no computations, 1: using corotational strain, 2: using full Green strain  Default value: 0

    :param vonMisesPerElement: von Mises Stress per element  Default value: []

    :param vonMisesPerNode: von Mises Stress per node  Default value: []

    :param vonMisesStressColors: Vector of colors describing the VonMises stress  Default value: []

    :param showStressColorMap: Color map used to show stress values  Default value: 

    :param showStressAlpha: Alpha for vonMises visualisation  Default value: 1.0

    :param showVonMisesStressPerNode: draw points  showing vonMises stress interpolated in nodes  Default value: 0

    :param updateStiffness: udpate structures (precomputed in init) using stiffness parameters in each iteration (set listening=1)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, initialPoints=initialPoints, method=method, poissonRatio=poissonRatio, youngModulus=youngModulus, localStiffnessFactor=localStiffnessFactor, updateStiffnessMatrix=updateStiffnessMatrix, computeGlobalMatrix=computeGlobalMatrix, plasticMaxThreshold=plasticMaxThreshold, plasticYieldThreshold=plasticYieldThreshold, plasticCreep=plasticCreep, gatherPt=gatherPt, gatherBsize=gatherBsize, drawHeterogeneousTetra=drawHeterogeneousTetra, drawAsEdges=drawAsEdges, computeVonMisesStress=computeVonMisesStress, vonMisesPerElement=vonMisesPerElement, vonMisesPerNode=vonMisesPerNode, vonMisesStressColors=vonMisesStressColors, showStressColorMap=showStressColorMap, showStressAlpha=showStressAlpha, showVonMisesStressPerNode=showVonMisesStressPerNode, updateStiffness=updateStiffness)
    return "TetrahedronFEMForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SubsetTopologicalMapping

.. autofunction:: SubsetTopologicalMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SubsetTopologicalMapping(self, **kwargs):
    """
    This class is a specific implementation of TopologicalMapping where the destination topology is a subset of the source topology. The implementation currently assumes that both topologies have been initialized correctly.



    """
    params = dict()
    return "SubsetTopologicalMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component EllipsoidForceField

.. autofunction:: EllipsoidForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def EllipsoidForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, contacts=None, center=None, vradius=None, stiffness=None, damping=None, color=None, **kwargs):
    """
    Repulsion applied by an ellipsoid toward the exterior or the interior


    :param name: object name  Default value: EllipsoidForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param contacts: Contacts  Default value: 

    :param center: ellipsoid center  Default value: [[0.0, 0.0, 0.0]]

    :param vradius: ellipsoid radius  Default value: [[0.0, 0.0, 0.0]]

    :param stiffness: force stiffness (positive to repulse outward, negative inward)  Default value: 500.0

    :param damping: force damping  Default value: 5.0

    :param color: ellipsoid color. (default=0,0.5,1.0,1.0)  Default value: [[0.0, 0.5, 1.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, contacts=contacts, center=center, vradius=vradius, stiffness=stiffness, damping=damping, color=color)
    return "EllipsoidForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CorotationalStrainMapping

.. autofunction:: CorotationalStrainMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CorotationalStrainMapping(self, **kwargs):
    """
    Map Deformation Gradients to Corotational Strain (small local deformations).



    """
    params = dict()
    return "CorotationalStrainMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BoxStiffSpringForceField

.. autofunction:: BoxStiffSpringForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BoxStiffSpringForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, stiffness=None, damping=None, showArrowSize=None, drawMode=None, spring=None, indices1=None, indices2=None, length=None, box_object1=None, box_object2=None, factorRestLength=None, forceOldBehavior=None, **kwargs):
    """
    Set Spring between the points inside a given box


    :param name: object name  Default value: BoxStiffSpringForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param stiffness: uniform stiffness for the all springs  Default value: 100.0

    :param damping: uniform damping for the all springs  Default value: 5.0

    :param showArrowSize: size of the axis  Default value: 0.00999999977648

    :param drawMode: The way springs will be drawn:
- 0: Line
- 1:Cylinder
- 2: Arrow  Default value: 0

    :param spring: pairs of indices, stiffness, damping, rest length  Default value: 

    :param indices1: Indices of the source points on the first model  Default value: []

    :param indices2: Indices of the fixed points on the second model  Default value: []

    :param length: uniform length of all springs  Default value: 0.0

    :param box_object1: Box for the object1 where springs will be attached  Default value: [[0.0, 0.0, 0.0, 1.0, 1.0, 1.0]]

    :param box_object2: Box for the object2 where springs will be attached  Default value: [[0.0, 0.0, 0.0, 1.0, 1.0, 1.0]]

    :param factorRestLength: Factor used to compute the rest length of the springs generated  Default value: 1.0

    :param forceOldBehavior: Keep using the old behavior  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, stiffness=stiffness, damping=damping, showArrowSize=showArrowSize, drawMode=drawMode, spring=spring, indices1=indices1, indices2=indices2, length=length, box_object1=box_object1, box_object2=box_object2, factorRestLength=factorRestLength, forceOldBehavior=forceOldBehavior)
    return "BoxStiffSpringForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component VoxelGridLoader

.. autofunction:: VoxelGridLoader

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def VoxelGridLoader(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, hexahedra=None, voxelSize=None, resolution=None, ROI=None, header=None, segmentationHeader=None, idxInRegularGrid=None, bgValue=None, dataValue=None, generateHexa=None, **kwargs):
    """
    Voxel loader based on RAW files


    :param name: object name  Default value: VoxelGridLoader

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Invalid

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the object  Default value: 

    :param position: Coordinates of the nodes loaded  Default value: []

    :param hexahedra: Hexahedra loaded  Default value: []

    :param voxelSize: Dimension of one voxel  Default value: [[1.0, 1.0, 1.0]]

    :param resolution: Resolution of the voxel file  Default value: [[0, 0, 0]]

    :param ROI: Region of interest (xmin, ymin, zmin, xmax, ymax, zmax)  Default value: [[0, 0, 0, 65535, 65535, 65535]]

    :param header: Header size in bytes  Default value: 0

    :param segmentationHeader: Header size in bytes  Default value: 0

    :param idxInRegularGrid: indices of the hexa in the grid.  Default value: []

    :param bgValue: Background values (to be ignored)  Default value: []

    :param dataValue: Active data values  Default value: []

    :param generateHexa: Interpret voxel as either hexa or points  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, hexahedra=hexahedra, voxelSize=voxelSize, resolution=resolution, ROI=ROI, header=header, segmentationHeader=segmentationHeader, idxInRegularGrid=idxInRegularGrid, bgValue=bgValue, dataValue=dataValue, generateHexa=generateHexa)
    return "VoxelGridLoader", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MergeMeshes

.. autofunction:: MergeMeshes

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MergeMeshes(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, nbMeshes=None, npoints=None, position=None, edges=None, triangles=None, quads=None, polygons=None, tetrahedra=None, hexahedra=None, position1=None, position2=None, edges1=None, edges2=None, triangles1=None, triangles2=None, quads1=None, quads2=None, tetrahedra1=None, tetrahedra2=None, hexahedra1=None, hexahedra2=None, **kwargs):
    """
    Merge several meshes


    :param name: object name  Default value: MergeMeshes

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param nbMeshes: number of meshes to merge  Default value: 2

    :param npoints: Number Of out points  Default value: 0

    :param position: Output Vertices of the merged mesh  Default value: []

    :param edges: Output Edges of the merged mesh  Default value: []

    :param triangles: Output Triangles of the merged mesh  Default value: []

    :param quads: Output Quads of the merged mesh  Default value: []

    :param polygons: Output Polygons of the merged mesh  Default value: []

    :param tetrahedra: Output Tetrahedra of the merged mesh  Default value: []

    :param hexahedra: Output Hexahedra of the merged mesh  Default value: []

    :param position1: input positions for mesh 1  Default value: []

    :param position2: input positions for mesh 2  Default value: []

    :param edges1: input edges for mesh 1  Default value: []

    :param edges2: input edges for mesh 2  Default value: []

    :param triangles1: input triangles for mesh 1  Default value: []

    :param triangles2: input triangles for mesh 2  Default value: []

    :param quads1: input quads for mesh 1  Default value: []

    :param quads2: input quads for mesh 2  Default value: []

    :param tetrahedra1: input tetrahedra for mesh 1  Default value: []

    :param tetrahedra2: input tetrahedra for mesh 2  Default value: []

    :param hexahedra1: input hexahedra for mesh 1  Default value: []

    :param hexahedra2: input hexahedra for mesh 2  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, nbMeshes=nbMeshes, npoints=npoints, position=position, edges=edges, triangles=triangles, quads=quads, polygons=polygons, tetrahedra=tetrahedra, hexahedra=hexahedra, position1=position1, position2=position2, edges1=edges1, edges2=edges2, triangles1=triangles1, triangles2=triangles2, quads1=quads1, quads2=quads2, tetrahedra1=tetrahedra1, tetrahedra2=tetrahedra2, hexahedra1=hexahedra1, hexahedra2=hexahedra2)
    return "MergeMeshes", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ViewerSetting

.. autofunction:: ViewerSetting

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ViewerSetting(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, resolution=None, fullscreen=None, cameraMode=None, objectPickingMethod=None, **kwargs):
    """
    Configuration for the Viewer of your application


    :param name: object name  Default value: ViewerSetting

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param resolution: resolution of the Viewer  Default value: [[800, 600]]

    :param fullscreen: Fullscreen mode  Default value: 0

    :param cameraMode: Camera mode  Default value: Perspective

    :param objectPickingMethod: The method used to pick objects  Default value: Ray casting


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, resolution=resolution, fullscreen=fullscreen, cameraMode=cameraMode, objectPickingMethod=objectPickingMethod)
    return "ViewerSetting", params
